import 'dart:convert';
import 'dart:io';

import 'package:flutter/material.dart';

import '../../models/responses/bank_transfer_response/bank_transfer_response.dart';
import '../../utils/flutterwave_urls.dart';
import 'package:stripe_package/flutterwave222/core/flutterwave_error.dart';
import 'package:stripe_package/flutterwave222/models/requests/bank_transfer/bank_transfer_request.dart';
import 'package:stripe_package/flutterwave222/models/requests/verify_charge_request.dart';
import 'package:stripe_package/flutterwave222/models/responses/bank_transfer_response/bank_transfer_response.dart';
import 'package:stripe_package/flutterwave222/models/responses/charge_response.dart';
import 'package:stripe_package/flutterwave222/utils/flutterwave_urls.dart';
import 'package:http/http.dart' as http;
import 'package:stripe_package/flutterwave222/models/responses/bank_transfer_response/bank_transfer_response.dart';

class BankTransferPaymentManager {
  String publicKey;
  String currency;
  String amount;
  String email;
  String txRef;
  bool isDebugMode;
  String phoneNumber;
  int? frequency;
  int? duration;
  String? narration;
  bool? isPermanent;
  String? redirectUrl;

  /// Bank Transfer Payment Manager Constructor
  /// This is responsible for creating instances of BankTransferPaymentManager
  BankTransferPaymentManager({
    required this.publicKey,
    required this.currency,
    required this.amount,
    required this.email,
    required this.txRef,
    required this.isDebugMode,
    required this.phoneNumber,
    required this.frequency,
    required this.narration,
    this.duration,
    this.isPermanent,
    this.redirectUrl
  });

  /// Resposnsible for making payments with bank transfer
  /// it returns a bank transfer response or throws an error
  Future<BankTransferResponse> payWithBankTransfer(
      BankTransferRequest bankTransferRequest, http.Client client) async {
    final requestBody = bankTransferRequest.toJson();
    final url = FlutterwaveURLS.getBaseUrl(this.isDebugMode) + FlutterwaveURLS.BANK_TRANSFER;
    final uri = Uri.parse(url);
    try {
      final http.Response response = await client.post(uri,
          headers: {HttpHeaders.authorizationHeader: this.publicKey},
          body: requestBody);

      BankTransferResponse bankTransferResponse =
          BankTransferResponse.fromJson(json.decode(response.body));

      return bankTransferResponse;
    } catch (error) {
      throw (FlutterError(error.toString()));
    }
  }

  /// Responsible for verifying payments made with bank transfers
  /// it returns an instance of ChargeResponse or throws an error
  Future<ChargeResponse> verifyPayment(final String flwRef, final http.Client client) async {
    final url = FlutterwaveURLS.getBaseUrl(this.isDebugMode) + FlutterwaveURLS.VERIFY_TRANSACTION;
    final uri = Uri.parse(url);
    final VerifyChargeRequest verifyRequest = VerifyChargeRequest(flwRef);
    final payload = verifyRequest.toJson();
    try {
      final http.Response response = await client.post(uri,
          headers: {
            HttpHeaders.authorizationHeader: this.publicKey,
            HttpHeaders.contentTypeHeader: "application/json"
          },
          body: payload);

      final ChargeResponse cardResponse =
      ChargeResponse.fromJson(jsonDecode(response.body));
      return cardResponse;
    } catch (error) {
      throw(FlutterWaveError(error.toString()));
    }
  }
}
