library stripe_package;

import 'package:flutter/material.dart';
import 'package:flutter_dotenv/flutter_dotenv.dart';
import 'package:flutter_stripe/flutter_stripe.dart';
import 'dart:convert';

import 'package:http/http.dart' as http;

import 'package:stripe_package/paypal.dart';

import 'Transaction.dart';

// void main() async {
//   //Initialize Flutter Binding
//   WidgetsFlutterBinding.ensureInitialized();
//
//   //Assign publishable key to flutter_stripe
//   Stripe.publishableKey =
//   "pk_test_51MJXzuSDkCn9xty0DyimJzuQrf0Hlw2Hq8hJZwy0dkyLXZgO8zoHlP1LN5APQcLNiTOFPOFoKpRWJGKZTii5YOyl00p0rwuhO1";
//
//   //Load our .env file that contains our Stripe Secret key
//   // await dotenv.load(fileName: "assets/.env");
//   String stripesecret = "sk_test_51MJXzuSDkCn9xty0LbtHfpeOH68LYJnLDcqmKPL6YL75LiSnpWmM1PN4Qo6juqiqjWHD4HVmjD97ulraY6Mb9ZG400McRfjRPO";
//
//   runApp(MaterialApp(
//       debugShowCheckedModeBanner: false,
//       home: StripePackage()));
// }

class Home extends StatefulWidget {
  const Home({
    Key? key,
    this.buttonText = "Stripe",
    this.name = "vikrant",
    this.amount = 5000,
    this.currency = "INR",
    this.width = 100,
    this.height = 50,
    this.buttonColor,
    this.textTextColor = Colors.white,
  }) : super(key: key);

  final String? buttonText;
  final String? name;
  final int? amount;
  final String? currency;
  final double? width;
  final double height;
  final MaterialStateProperty<Color?>? buttonColor;
  final Color? textTextColor;

  @override
  State<Home> createState() => _HomeState();

}

class _HomeState extends State<Home> {
  Map<String, dynamic>? paymentIntent;

  @override
  Widget build(BuildContext context) {
    return Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            TextButton(
              child: Text(widget.buttonText.toString()),
              onPressed: () async {
                await makePayment();
              },
            ),
          ],
        ),
      );

  }

  Future<void> makePayment() async {
    try {
      paymentIntent = await createPaymentIntent(
          widget.amount.toString(), widget.currency.toString());

      //STEP 2: Initialize Payment Sheet
      await Stripe.instance
          .initPaymentSheet(
              paymentSheetParameters: SetupPaymentSheetParameters(
                  paymentIntentClientSecret: paymentIntent![
                      'client_secret'], //Gotten from payment intent
                  style: ThemeMode.dark,
                  merchantDisplayName: widget.name.toString()))
          .then((value) {});

      //STEP 3: Display Payment sheet
      displayPaymentSheet();
    } catch (err) {
      throw Exception(err);
    }
  }

  displayPaymentSheet() async {
    try {
      await Stripe.instance.presentPaymentSheet().then((value) {
        showDialog(
            context: context,
            builder: (_) => AlertDialog(
                  content: Column(
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      Icon(
                        Icons.check_circle,
                        color: Colors.green,
                        size: 100.0,
                      ),
                      SizedBox(height: 10.0),
                      Text("Payment Successful!"),
                    ],
                  ),
                ));

        paymentIntent = null;
      }).onError((error, stackTrace) {
        throw Exception(error);
      });
    } on StripeException catch (e) {
      print('Error is:---> $e');
      AlertDialog(
        content: Column(
          mainAxisSize: MainAxisSize.min,
          children: [
            Row(
              children: const [
                Icon(
                  Icons.cancel,
                  color: Colors.red,
                ),
                Text("Payment Failed"),
              ],
            ),
          ],
        ),
      );
    } catch (e) {
      print('$e');
    }
  }

  createPaymentIntent(String amount, String currency) async {
    try {
      //Request body
      Map<String, dynamic> body = {
        'amount': calculateAmount(amount),
        'currency': currency,
      };

      //Make post request to Stripe
      var response = await http.post(
        Uri.parse('https://api.stripe.com/v1/payment_intents'),
        headers: {
          'Authorization':
              'Bearer sk_test_51MJXzuSDkCn9xty0LbtHfpeOH68LYJnLDcqmKPL6YL75LiSnpWmM1PN4Qo6juqiqjWHD4HVmjD97ulraY6Mb9ZG400McRfjRPO',
          'Content-Type': 'application/x-www-form-urlencoded'
        },
        body: body,
      );
      return json.decode(response.body);
    } catch (err) {
      throw Exception(err.toString());
    }
  }

  calculateAmount(String amount) {
    final calculatedAmout = (int.parse(amount)) * 100;
    return calculatedAmout.toString();
  }
}
